##  Rejecting Discovered Items in Bulk
To reject multiple items at once, follow these steps:
  1. Select the items that you want to reject, or select the Discovery Item checkbox to select all.
Use filters to narrow down the list for selection.
For example, you can filter by an integration source and select only those items.
  2. Choose Reject.
